import { Chain, Network, Platform, PlatformToChains } from "@wormhole-foundation/sdk-base";
import { AccountAddress, ChainAddress, NativeAddress, TokenAddress, UniversalOrNative } from "../address";
import "../payloads/tokenBridge";
import { TokenId } from "../types";
import { UnsignedTransaction } from "../unsignedTransaction";
import { ProtocolPayload, ProtocolVAA } from "../vaa";
export declare const ErrNotWrapped: (token: string) => Error;
export declare namespace TokenBridge {
    type VAA<PayloadName extends string> = ProtocolVAA<"TokenBridge", PayloadName>;
    type Payload<PayloadName extends string> = ProtocolPayload<"TokenBridge", PayloadName>;
    const getTransferDiscriminator: () => import("../vaa").PayloadDiscriminator<"TokenBridge:Transfer" | "TokenBridge:TransferWithPayload", false>;
}
export interface TokenBridge<N extends Network, P extends Platform, C extends PlatformToChains<P>> {
    isWrappedAsset(nativeAddress: TokenAddress<C>): Promise<boolean>;
    getOriginalAsset(nativeAddress: TokenAddress<C>): Promise<TokenId<Chain>>;
    getWrappedNative(): Promise<NativeAddress<C>>;
    hasWrappedAsset(foreignToken: TokenId<Chain>): Promise<boolean>;
    getWrappedAsset(foreignToken: TokenId<Chain>): Promise<NativeAddress<C>>;
    isTransferCompleted(vaa: TokenBridge.VAA<"Transfer" | "TransferWithPayload">): Promise<boolean>;
    createAttestation(token: TokenAddress<C>, payer?: UniversalOrNative<C>): AsyncGenerator<UnsignedTransaction<N, C>>;
    submitAttestation(vaa: TokenBridge.VAA<"AttestMeta">, payer?: UniversalOrNative<C>): AsyncGenerator<UnsignedTransaction<N, C>>;
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, token: TokenAddress<C>, amount: bigint, payload?: Uint8Array): AsyncGenerator<UnsignedTransaction<N, C>>;
    redeem(sender: AccountAddress<C>, vaa: TokenBridge.VAA<"Transfer" | "TransferWithPayload">, unwrapNative?: boolean): AsyncGenerator<UnsignedTransaction<N, C>>;
}
export interface AutomaticTokenBridge<N extends Network, P extends Platform, C extends PlatformToChains<P>> {
    transfer(sender: AccountAddress<C>, recipient: ChainAddress, token: TokenAddress<C>, amount: bigint, nativeGas?: bigint): AsyncGenerator<UnsignedTransaction<N, C>>;
    redeem(sender: AccountAddress<C>, vaa: TokenBridge.VAA<"TransferWithPayload">): AsyncGenerator<UnsignedTransaction<N, C>>;
    getRelayerFee(sender: AccountAddress<C>, recipient: ChainAddress, token: TokenAddress<C>): Promise<bigint>;
    isRegisteredToken(token: TokenAddress<C>): Promise<boolean>;
    getRegisteredTokens(): Promise<TokenAddress<C>[]>;
    nativeTokenAmount(token: TokenAddress<C>, amount: bigint): Promise<bigint>;
    maxSwapAmount(token: TokenAddress<C>): Promise<bigint>;
}
//# sourceMappingURL=tokenBridge.d.ts.map