"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildConfig = exports.isTransactionIdentifier = exports.nativeChainAddress = exports.isTokenId = void 0;
const sdk_base_1 = require("@wormhole-foundation/sdk-base");
const address_1 = require("./address");
const contracts_1 = require("./contracts");
const signer_1 = require("./signer");
const universalAddress_1 = require("./universalAddress");
function isTokenId(thing) {
    return (typeof thing === "object" &&
        typeof thing.address !== undefined &&
        (0, sdk_base_1.isChain)(thing.chain));
}
exports.isTokenId = isTokenId;
function nativeChainAddress(s, a) {
    let chain;
    let address;
    // its a chain address
    if (a) {
        // We might be passed a universal address as a string
        // First try to decode it as native, otherwise try
        // to decode it as universal and convert it to native
        chain = s;
        try {
            address = (0, address_1.toNative)(chain, a);
        }
        catch {
            address = universalAddress_1.UniversalAddress.instanceof(a)
                ? a.toNative(chain)
                : new universalAddress_1.UniversalAddress(a).toNative(chain);
        }
    }
    else if ((0, signer_1.isSigner)(s)) {
        chain = s.chain();
        address = (0, address_1.toNative)(s.chain(), s.address());
    }
    else if (isTokenId(s)) {
        // otherwise TokenId
        chain = s.chain;
        address = s.address.toNative(s.chain);
    }
    else {
        throw new Error("Invalid nativeChainAddress parameters");
    }
    return { chain, address };
}
exports.nativeChainAddress = nativeChainAddress;
function isTransactionIdentifier(thing) {
    return thing.chain !== undefined && thing.txid !== undefined;
}
exports.isTransactionIdentifier = isTransactionIdentifier;
function buildConfig(n) {
    const cc = sdk_base_1.chains
        .map((c) => {
        const platform = (0, sdk_base_1.chainToPlatform)(c);
        let nativeChainId = "";
        try {
            nativeChainId = sdk_base_1.nativeChainIds.networkChainToNativeChainId.get(n, c);
        }
        catch { }
        return {
            key: c,
            platform,
            network: n,
            chainId: (0, sdk_base_1.toChainId)(c),
            finalityThreshold: sdk_base_1.finality.finalityThreshold.get(c) ?? 0,
            blockTime: sdk_base_1.finality.blockTime(c),
            contracts: (0, contracts_1.getContracts)(n, c),
            nativeTokenDecimals: sdk_base_1.decimals.nativeDecimals(platform),
            nativeChainId,
            explorer: sdk_base_1.explorer.explorerConfigs(n, c),
            rpc: sdk_base_1.rpc.rpcAddress(n, c),
        };
    })
        .reduce((acc, curr) => {
        return { ...acc, [curr.key]: curr };
    }, {});
    return cc;
}
exports.buildConfig = buildConfig;
//# sourceMappingURL=types.js.map